#region using
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Globalization;
using System.IO;
using System.Net;
using System.Net.Sockets;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.ServiceModel.Design;
using System.Text;
using System.Xml;
#endregion
namespace Microsoft.ServiceModel.Samples.Transport
{
   public class TcpChannelFactory : ChannelFactoryBase
   {
      #region member variables
      const int maxBufferSize = 64 * 1024;
      BufferManager bufferManager;
      MessageEncoderFactory encoderFactory;
      #endregion

      public TcpChannelFactory(IMessageEncodingBindingElement encodingElement)
      {
         if (encodingElement == null)
         {
            throw new ArgumentNullException("encodingElement");
         }

         this.encoderFactory = encodingElement.CreateMessageEncoderFactory();
         this.bufferManager =
             BufferManager.CreateBufferManager(512 * 1024, maxBufferSize);
      }

      public override MessageVersion MessageVersion
      {
         get { return this.encoderFactory.MessageVersion; }
      }

      public override string Scheme
      {
         // change this to soap.tcp for WSE 3.0 interop
         get { return "my.tcp"; }
      }

      // will be in Binding Element for Beta 2 (IChannelFactory<T>)
      public override bool CanCreateChannel<TChannel>()
      {
         if (typeof(TChannel) == typeof(IDuplexSessionChannel))
            return true;

         return false;
      }

      protected override TChannel OnCreateChannel<TChannel>(
          EndpointAddress remoteAddress, Uri via)
      {
         return (TChannel)(object)new ClientTcpDuplexSessionChannel(
             encoderFactory, bufferManager, remoteAddress, via, this);
      }
   }
}